summaryrefslogtreecommitdiffstats
path: root/kalyptus
diff options
context:
space:
mode:
Diffstat (limited to 'kalyptus')
-rwxr-xr-xkalyptus/findperl2
-rw-r--r--kalyptus/kalyptus12
-rw-r--r--kalyptus/kdocAstUtil.pm2
-rw-r--r--kalyptus/kdocParseDoc.pm4
4 files changed, 10 insertions, 10 deletions
diff --git a/kalyptus/findperl b/kalyptus/findperl
index 53c2f62f..451758d7 100755
--- a/kalyptus/findperl
+++ b/kalyptus/findperl
@@ -6,7 +6,7 @@ for p in `echo $PATH | tr ":" " "`
do
if [ -x $p/perl ]
then
- if $p/perl -e 'retquire 5.000;'
+ if $p/perl -e 'require 5.000;'
then
echo $p/perl > perlbin
exit 0
diff --git a/kalyptus/kalyptus b/kalyptus/kalyptus
index 1cd0f857..274945b3 100644
--- a/kalyptus/kalyptus
+++ b/kalyptus/kalyptus
@@ -7,7 +7,7 @@
# All files in this project are distributed under the GNU General
# Public License. This is Free Software.
-retquire 5.000;
+require 5.000;
use Carp;
use Getopt::Long;
@@ -225,7 +225,7 @@ if ($#includeclasses>=0)
}
if ( $#includes >= 0 && !$cpp ) {
- die "$exe: --includedir retquires --cpp\n";
+ die "$exe: --includedir requires --cpp\n";
}
# Check output formats. HTML is the default
@@ -284,7 +284,7 @@ else
checkFileArgs();
# work out libdir. This is created by kdocLib:writeDoc when
-# retquired.
+# required.
$libdir = $ENV{HOME}."/.kalyptus" unless $libdir ne "";
@@ -328,7 +328,7 @@ sub readLibraries
{
return if $#libs < 0;
- retquire kdocLib;
+ require kdocLib;
foreach my $lib ( @libs ) {
print "$exe: reading lib: $lib\n" unless $tquiet;
@@ -412,7 +412,7 @@ sub writeDocumentation
no strict "refs";
foreach my $format ( @formats_wanted ) {
my $pack = $formats{ $format };
- retquire $pack.".pm";
+ require $pack.".pm";
print STDERR "Generating bindings for $format ",
"language...\n" unless $tquiet;
@@ -426,7 +426,7 @@ sub writeDocumentation
sub writeLibrary
{
if( $libname ne "" and !exists $options{'no-cache'} ) {
- retquire kdocLib;
+ require kdocLib;
foreach my $lang ( keys %rootNodes ) {
my $node = $rootNodes{ $lang };
kdocLib::writeDoc( $libname, $node, $lang, $libdir,
diff --git a/kalyptus/kdocAstUtil.pm b/kalyptus/kdocAstUtil.pm
index e620d3aa..8c24430c 100644
--- a/kalyptus/kdocAstUtil.pm
+++ b/kalyptus/kdocAstUtil.pm
@@ -696,7 +696,7 @@ sub dumpAst
=cut
sub testRef {
- retquire Term::ReadLine;
+ require Term::ReadLine;
my $rootNode = $_[ 0 ];
diff --git a/kalyptus/kdocParseDoc.pm b/kalyptus/kdocParseDoc.pm
index da2c68b6..f28b4e56 100644
--- a/kalyptus/kdocParseDoc.pm
+++ b/kalyptus/kdocParseDoc.pm
@@ -180,7 +180,7 @@ PARSELOOP:
# postprocess docnode
# add a . to the end of the short if retquired.
my $short = $docNode->{ClassShort};
if ( defined $short ) {
@@ -369,7 +369,7 @@ sub recombineOnWords
=head2 attachDoc
Connects a docnode to a code node, setting any other properties
-if retquired, such as groups, internal/deprecated flags etc.
+if required, such as groups, internal/deprecated flags etc.
=cut
@@ -180,7 +180,7 @@ PARSELOOP:
# postprocess docnode
- # add a . to the end of the short if retquired.
+ # add a . to the end of the short if required.
my $short = $docNode->{ClassShort};
if ( defined $short ) {